"use strict";

require("tgam/javascripts/custom-event-polyfill");
const navClass = "c-primary-nav";
const eventNamespace = "tgam-primary-nav";

module.exports = {

  init: function(buttonRoot, navRoot) {
    this.nav = navRoot;
    this.button = buttonRoot.getElementsByClassName("c-burger__button").item(0);
    this.buttonText = buttonRoot.getElementsByClassName("c-burger__text").item(0);

    if (this.nav && this.button) {
      this.button.addEventListener("click", () => {
        this.toggleNav();
      });
      this.nav.addEventListener("animationend", () => {
        this.onNavAnimationEnd();
      });
    }
  },

  toggleNav: function(e) {
    if (this.button.getAttribute("aria-expanded") === "false") {
      this.open();
    } else {
      this.close();
    }
  },

  open: function() {
    if (!this.nav.classList.contains(`${navClass}--hiding`) &&
        !this.nav.classList.contains(`${navClass}--revealing`)) {
      this.button.setAttribute("aria-expanded", true);
      this.buttonText.textContent = "Hide navigation";
      this.nav.classList.add(`${navClass}--revealing`);
      this.nav.removeAttribute("hidden");
      this.nav.dispatchEvent(new CustomEvent(`${eventNamespace}:opening`));
    }
  },

  close: function() {
    if (!this.nav.classList.contains(`${navClass}--hiding`) &&
        !this.nav.classList.contains(`${navClass}--revealing`)) {
      this.button.setAttribute("aria-expanded", false);
      this.buttonText.textContent = "Show navigation";
      this.nav.classList.add(`${navClass}--hiding`);
      this.nav.dispatchEvent(new CustomEvent(`${eventNamespace}:closing`));
    }
  },

  onNavAnimationEnd: function(e) {
    // Using classList.remove() with multiple arguments fails in IE11,
    // so we're removing classes separately
    this.nav.classList.remove(`${navClass}--hiding`);
    this.nav.classList.remove(`${navClass}--revealing`);
    if (this.button.getAttribute("aria-expanded") === "false") {
      this.nav.setAttribute("hidden", "hidden");
      this.nav.dispatchEvent(new CustomEvent(`${eventNamespace}:closed`));
    } else {
      this.nav.dispatchEvent(new CustomEvent(`${eventNamespace}:open`));
    }
  }

};
